# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid debug* files interfering with manifest test:
%global debug_package %{nil}

# Similarly for .package_note* files
%undefine _package_note_file

# TODO: BR: perl(Test::Pod::LinkCheck) when available

Name:		perl-Test-Portability-Files
Version:	0.10
Release:	15.%{__distinit}%{__distvers}
Summary:	Check file names portability
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Portability-Files
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Portability-Files-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Runtime
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::Manifest)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(blib)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(utf8)
%if 0%{!?perl_bootstrap:1}
# Author Tests
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Mojibake)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Synopsis)
BuildRequires:	perl(Test::Version)
# Release Tests
BuildRequires:	perl(Test::CPAN::Changes)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::CPAN::Meta::JSON)
BuildRequires:	perl(Test::DistManifest)
BuildRequires:	perl(Test::Kwalitee) >= 1.21
BuildRequires:	perl(Test::More) >= 0.96
BuildRequires:	perl(Test::Vars)
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module is used to check the portability across operating systems of the
names of the files present in the distribution of a module. The tests use the
advice given in "Files and Filesystems" in perlport. The author of a
distribution can select which tests to execute.

To use this module, simply copy the code from the synopsis in a test file named
t/portfs.t for example, and add it to your MANIFEST. You can delete the call to
options() to enable only most common tests.

By default, not all tests are enabled because some are judged too cumbersome to
be practical, especially since some of the most limited platforms (like MS-DOS)
seem to be no longer supported. Here are the default options:

 * use_file_find is not enabled (check only the names as listed in MANIFEST)
 * test_amiga_length is enabled
 * test_ansi_chars is enabled
 * test_case is enabled
 * test_dos_length is not enabled
 * test_mac_length is enabled
 * test_one_dot is enabled
 * test_space is enabled
 * test_special_chars is enabled
 * test_symlink is enabled
 * test_vms_length is enabled
 * test_windows_reserved is enabled

To change any option, please see options().

%prep
%setup -q -n Test-Portability-Files-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test %{!?perl_bootstrap:AUTHOR_TESTING=1 RELEASE_TESTING=1}

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Portability::Files.3*

%changelog
* Mon Jun 26 2023 Paul Howarth <paul@city-fan.org> - 0.10-15
- Use SPDX-format license tag

* Fri Mar 18 2022 Paul Howarth <paul@city-fan.org> - 0.10-10
- Work around package note files breaking t/release-dist-manifest.t
- Use %%license unconditionally

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 0.10-7
- Perl 5.32 rebuild

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 0.10-3
- Perl 5.30 rebuild

* Mon Jan  7 2019 Paul Howarth <paul@city-fan.org> - 0.10-1
- Update to 0.10
  - Update POD about Windows reserved file tests
  - Add tests for Windows reserved file tests
  - Fix bug with Windows reserved file tests so that files like "con.dat.txt"
    will fail
  - Add missing error text for Windows reserved tests
  - Add Pod::Weaver configuration
- Switch upstream from search.cpan.org to metacpan.org

* Tue Jan  2 2018 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09
  - Add windows_reserved option to test for Windows reserved filenames
  - Add tests, now requires Perl 5.008
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.96
  - Can always run all tests now

* Tue Jan 10 2017 Paul Howarth <paul@city-fan.org> - 0.07-2
- Test::Kwalitee ≥ 1.21 now available back to Fedora 9

* Thu Sep 22 2016 Paul Howarth <paul@city-fan.org> - 0.07-1
- Update to 0.07
  - Relax the ansi_chars check to allow for . and _ as the leading character
    of a filename
- Update patch for building with old Test::More versions

* Mon May 16 2016 Paul Howarth <paul@city-fan.org> - 0.06-7
- Don't try to run the author tests when bootstrapping
- BR: perl-generators where possible
- Simplify find command using -delete

* Wed Jul  1 2015 Paul Howarth <paul@city-fan.org> - 0.06-5
- Disable use of Test::Vars with Perl 5.22
  (https://github.com/gfx/p5-Test-Vars/issues/11)
- Disable use of Test::CPAN::Changes with Perl 5.10.0, where it triggers an
  assertion failure in Fedora

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 0.06-4
- Perl 5.22 bootstrap

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.06-3
- Drop support for building with ExtUtils::MakeMaker < 6.30
- BR: perl(Test::CPAN::Changes) and perl(Test::Synopsis) unconditionally
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible
- Avoid Test::Kwalitee as the test suite now fails with it due to unusual
  directory layout

* Fri Dec  7 2012 Paul Howarth <paul@city-fan.org> - 0.06-2
- Don't run author and release tests when bootstrapping

* Tue Nov 13 2012 Paul Howarth <paul@city-fan.org> - 0.06-1
- Update to 0.06
  - Created git repository on github.com
  - Converted to Dist::Zilla
  - Fixed options cannot take a false value (CPAN RT#21631)
  - Disabled AmigaOS and Mac OS Classic tests by default because they are no
    longer supported by Perl itself (CPAN RT#12182)
  - Updated synopsis to show recommended author-only usage (CPAN RT#43948)
- This release by ABRAXXA -> update source URL
- Add buildreqs for newly-added author and release tests
- Add patch to support building with ExtUtils::MakeMaker < 6.03
- Add patch to support building with Test::More < 0.88
- Disable debuginfo generation to avoid manifest issues
- LICENSE.Artistic and LICENSE.GPL no longer included upstream
- Explicitly run author and release tests
- Extend %%description

* Sat Jun 30 2012 Paul Howarth <paul@city-fan.org> - 0.05-15
- BR:/R: perl(Exporter)
- BR: perl(ExtUtils::Manifest), perl(File::Spec) and perl(Test::Builder)
- Use a patch to fix character encoding rather than scripted iconv
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul  6 2011 Paul Howarth <paul@city-fan.org> - 0.05-13
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.05-11
- Rebuild for perl 5.12.1 in Rawhide

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 0.05-10
- Fix dist tag for RHEL-6 Beta

* Fri Feb 12 2010 Paul Howarth <paul@city-fan.org> - 0.05-9
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Thu May  7 2009 Paul Howarth <paul@city-fan.org> - 0.05-8
- Import from Fedora

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Mar  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-6
- Rebuild for new perl

* Sun Dec 30 2007 Ralf Corsépius <rc040203@freenet.de> - 0.05-5
- BR: perl(Test::More).
- BR: perl(Test::Pod), perl(Test::Pod::Coverage).
- Adjust License-tag.

* Wed Apr 18 2007 Steven Pritchard <steve@kspei.com> 0.05-4
- Use fixperms macro instead of our own chmod incantation.
- BR ExtUtils::MakeMaker.

* Sat Sep 16 2006 Steven Pritchard <steve@kspei.com> 0.05-3
- Fix find option order.

* Fri May 12 2006 Steven Pritchard <steve@kspei.com> 0.05-2
- Use Makefile.PL temporarily to work around Module::Build breakage.

* Fri May 12 2006 Steven Pritchard <steve@kspei.com> 0.05-1
- Specfile autogenerated by cpanspec 1.66.
